#ifndef MSP_GL_VIEW_H_
#define MSP_GL_VIEW_H_

#include <list>
#include <sigc++/trackable.h>
#include <msp/graphics/glcontext.h>
#include <msp/graphics/window.h>

namespace Msp {
namespace GL {

class Camera;
class Framebuffer;
class Renderable;

/**
Manages the presentation of rendering results on the screen.
*/
class View: public sigc::trackable
{
private:
	Graphics::Window &window;
	Graphics::GLContext &context;
	Framebuffer &target;
	const Renderable *content;
	std::list<Camera *> synced_cameras;

public:
	View(Graphics::Window &, Graphics::GLContext &);

	Graphics::Window &get_window() { return window; }
	Graphics::GLContext &get_context() { return context; }
	unsigned get_width() const { return window.get_width(); }
	unsigned get_height() const { return window.get_height(); }
	float get_aspect() const { return static_cast<float>(get_width())/get_height(); }

	void set_content(const Renderable *);
	void synchronize_camera_aspect(Camera &);

	void render();

private:
	void window_resized(unsigned, unsigned);
};

} // namespace GL
} // namespace Msp

#endif
